/*
 *
 * Copyright (C) 2007-2013 Licensed to the Comunes Association (CA) under 
 * one or more contributor license agreements (see COPYRIGHT for details).
 * The CA licenses this file to you under the GNU Affero General Public 
 * License version 3, (the "License"); you may not use this file except in 
 * compliance with the License. This file is part of kune.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
package net.auroris.ColorPicker.client;

/**
 * Copyright (c) 2007, AurorisNET.
 *
 * Everyone is permitted to copy and distribute verbatim copies of this license
 * document, but changing it is not allowed.
 *
 * Preamble
 *
 * This license establishes the terms under which a given free software Package
 * may be copied, modified, distributed, and/or redistributed. The intent is
 * that the Copyright Holder maintains some artistic control over the
 * development of that Package while still keeping the Package available as open
 * source and free software.
 *
 * You are always permitted to make arrangements wholly outside of this license
 * directly with the Copyright Holder of a given Package. If the terms of this
 * license do not permit the full use that you propose to make of the Package,
 * you should contact the Copyright Holder and seek a different licensing
 * arrangement.
 *
 * Definitions
 *
 * "Copyright Holder" means the individual(s) or organization(s) named in the
 * copyright notice for the entire Package.
 *
 * "Contributor" means any party that has contributed code or other material to
 * the Package, in accordance with the Copyright Holder's procedures.
 *
 * "You" and "your" means any person who would like to copy, distribute, or
 * modify the Package.
 *
 * "Package" means the collection of files distributed by the Copyright Holder,
 * and derivatives of that collection and/or of those files. A given Package may
 * consist of either the Standard Version, or a Modified Version.
 *
 * "Distribute" means providing a copy of the Package or making it accessible to
 * anyone else, or in the case of a company or organization, to others outside
 * of your company or organization.
 *
 * "Distributor Fee" means any fee that you charge for Distributing this Package
 * or providing support for this Package to another party. It does not mean
 * licensing fees.
 *
 * "Standard Version" refers to the Package if it has not been modified, or has
 * been modified only in ways explicitly requested by the Copyright Holder.
 *
 * "Modified Version" means the Package, if it has been changed, and such
 * changes were not explicitly requested by the Copyright Holder.
 *
 * "Original License" means this Artistic License as Distributed with the
 * Standard Version of the Package, in its current version or as it may be
 * modified by The Perl Foundation in the future.
 *
 * "Source" form means the source code, documentation source, and configuration
 * files for the Package.
 *
 * "Compiled" form means the compiled bytecode, object code, binary, or any
 * other form resulting from mechanical transformation or translation of the
 * Source form.
 *
 * Permission for Use and Modification Without Distribution
 *
 * (1) You are permitted to use the Standard Version and create and use Modified
 * Versions for any purpose without restriction, provided that you do not
 * Distribute the Modified Version.
 *
 * Permissions for Redistribution of the Standard Version
 *
 * (2) You may Distribute verbatim copies of the Source form of the Standard
 * Version of this Package in any medium without restriction, either gratis or
 * for a Distributor Fee, provided that you duplicate all of the original
 * copyright notices and associated disclaimers. At your discretion, such
 * verbatim copies may or may not include a Compiled form of the Package.
 *
 * (3) You may apply any bug fixes, portability changes, and other modifications
 * made available from the Copyright Holder. The resulting Package will still be
 * considered the Standard Version, and as such will be subject to the Original
 * License.
 *
 * Distribution of Modified Versions of the Package as Source
 *
 * (4) You may Distribute your Modified Version as Source (either gratis or for
 * a Distributor Fee, and with or without a Compiled form of the Modified
 * Version) provided that you clearly document how it differs from the Standard
 * Version, including, but not limited to, documenting any non-standard
 * features, executables, or modules, and provided that you do at least ONE of
 * the following:
 *
 *      (a) make the Modified Version available to the Copyright Holder of the
 *          Standard Version, under the Original License, so that the Copyright
 *          Holder may include your modifications in the Standard Version.
 *
 *      (b) ensure that installation of your Modified Version does not prevent
 *          the user installing or running the Standard Version. In addition,
 *          the Modified Version must bear a name that is different from the
 *          name of the Standard Version.
 *
 *      (c) allow anyone who receives a copy of the Modified Version to make the
 *          Source form of the Modified Version available to others under
 *
 *          (i) the Original License or
 *
 *          (ii) a license that permits the licensee to freely copy, modify and
 *              redistribute the Modified Version using the same licensing terms
 *              that apply to the copy that the licensee received, and requires
 *              that the Source form ofthe Modified Version, and of any works
 *              derived from it, be made freely available in that license fees
 *              are prohibited but Distributor Fees are allowed.
 *
 * Distribution of Compiled Forms of the Standard Version or Modified Versions
 * without the Source
 *
 * (5) You may Distribute Compiled forms of the Standard Version without the
 * Source, provided that you include complete instructions on how to get the
 * Source of the Standard Version. Such instructions must be valid at the time
 * of your distribution. If these instructions, at any time while you are
 * carrying out such distribution, become invalid, you must provide new
 * instructions on demand or cease further distribution. If you provide valid
 * instructions or cease distribution within thirty days after you become aware
 * that the instructions are invalid, then you do not forfeit any of your rights
 * under this license.
 *
 * (6) You may Distribute a Modified Version in Compiled form without the
 * Source, provided that you comply with Section 4 with respect to the Source of
 * the Modified Version.
 *
 * Aggregating or Linking the Package
 *
 * (7) You may aggregate the Package (either the Standard Version or Modified
 * Version) with other packages and Distribute the resulting aggregation
 * provided that you do not charge a licensing fee for the Package. Distributor
 * Fees are permitted, and licensing fees for other components in the
 * aggregation are permitted. The terms of this license apply to the use and
 * Distribution of the Standard or Modified Versions as included in the
 * aggregation.
 *
 * (8) You are permitted to link Modified and Standard Versions with other
 * works, to embed the Package in a larger work of your own, or to build
 * stand-alone binary or bytecode versions of applications that include the
 * Package, and Distribute the result without restriction, provided the result
 * does not expose a direct interface to the Package.
 *
 * Items That are Not Considered Part of a Modified Version
 *
 * (9) Works (including, but not limited to, modules and scripts) that merely
 * extend or make use of the Package, do not, by themselves, cause the Package
 * to be a Modified Version. In addition, such works are not considered parts of
 * the Package itself, and are not subject to the terms of this license.
 *
 * General Provisions
 *
 * (10) Any use, modification, and distribution of the Standard or Modified
 * Versions is governed by this Artistic License. By using, modifying or
 * distributing the Package, you accept this license. Do not use, modify, or
 * distribute the Package, if you do not accept this license.
 *
 * (11) If your Modified Version has been derived from a Modified Version made
 * by someone other than you, you are nevertheless required to ensure that your
 * Modified Version complies with the requirements of this license.
 *
 * (12) This license does not grant you the right to use any trademark, service
 * mark, tradename, or logo of the Copyright Holder.
 *
 * (13) This license includes the non-exclusive, worldwide, free-of-charge
 * patent license to make, have made, use, offer to sell, sell, import and
 * otherwise transfer the Package with respect to any patent claims licensable
 * by the Copyright Holder that are necessarily infringed by the Package. If you
 * institute patent litigation (including a cross-claim or counterclaim) against
 * any party alleging that the Package constitutes direct or contributory patent
 * infringement, then this Artistic License to you shall terminate on the date
 * that such litigation is filed.
 *
 * (14) Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
 * AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES. THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, OR
 * NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY YOUR LOCAL LAW.
 * UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR CONTRIBUTOR WILL BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING IN ANY WAY
 * OUT OF THE USE OF THE PACKAGE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

import net.auroris.ColorPicker.client.images.ColorPickerImageResource;

import com.google.gwt.core.client.GWT;
import com.google.gwt.user.client.DOM;
import com.google.gwt.user.client.Event;
import com.google.gwt.user.client.Window;
import com.google.gwt.user.client.ui.HTML;
import com.google.gwt.user.client.ui.Image;

// TODO: Auto-generated Javadoc
/**
 * Implements the SliderMap control.
 *
 * @author vjrj@ourproject.org (Vicente J. Ruiz Jurado)
 */
public final class SliderMap extends HTML
{
    
    /** The Constant Blue. */
    public static final int Blue = 6;
    
    /** The Constant Brightness. */
    public static final int Brightness = 2;
    
    /** The Constant Green. */
    public static final int Green = 5;
    
    /** The Constant Hue. */
    public static final int Hue = 3;
    
    /** The Constant Red. */
    public static final int Red = 4;
    
    /** The Constant Saturation. */
    public static final int Saturation = 1;

    /** The color overlay. */
    private Image colorOverlay;
    
    /** The color underlay. */
    private Image colorUnderlay;
    
    /** The slider. */
    private Image slider;

    /** The cp image bundle. */
    private ColorPickerImageResource cpImageBundle;
    
    /** The parent. */
    private ColorPicker parent = null;

    /** The captured mouse. */
    private boolean capturedMouse = false;

    /**
     * *
     * Initialize the SliderMap -- default mode is Saturation.
     *
     * @param parent the parent
     */
    public SliderMap(ColorPicker parent)
    {
        super();

        this.parent = parent;

        setWidth("128px");
        setHeight("128px");

        cpImageBundle = (ColorPickerImageResource) GWT.create(ColorPickerImageResource.class);

        colorUnderlay = new Image(cpImageBundle.map_saturation());
        colorOverlay = new Image(cpImageBundle.map_saturation_overlay());
        slider = new Image(cpImageBundle.mappoint());

        DOM.appendChild(getElement(), colorUnderlay.getElement());
        DOM.appendChild(getElement(), colorOverlay.getElement());
        DOM.appendChild(getElement(), slider.getElement());

        DOM.setStyleAttribute(getElement(), "position", "absolute");
        DOM.setStyleAttribute(colorUnderlay.getElement(), "border", "1px solid black");
        DOM.setStyleAttribute(colorOverlay.getElement(), "border", "1px solid black");
    }

    /***
     * This method is called when a widget is attached to the browser's document.
     */
    @Override
    public void onAttach()
    {
        super.onAttach();

        DOM.setStyleAttribute(colorUnderlay.getElement(), "position", "absolute");
        DOM.setStyleAttribute(colorUnderlay.getElement(), "left", "0px");
        DOM.setStyleAttribute(colorUnderlay.getElement(), "top", "0px");
        DOM.setStyleAttribute(colorOverlay.getElement(), "position", "absolute");
        DOM.setStyleAttribute(colorOverlay.getElement(), "left", "0px");
        DOM.setStyleAttribute(colorOverlay.getElement(), "top", "0px");
        DOM.setStyleAttribute(slider.getElement(), "position", "absolute");
        DOM.setStyleAttribute(slider.getElement(), "left", "0px");
        DOM.setStyleAttribute(slider.getElement(), "top", "0px");
        setOverlayOpacity(100);
    }

    /**
     * Fired whenever a browser event is received.
     * @param event Event to process
     */
    @Override
    public void onBrowserEvent(Event event)
    {
        super.onBrowserEvent(event);

        switch (DOM.eventGetType(event))
        {
            case Event.ONMOUSEUP:
                Event.releaseCapture(this.getElement());
                capturedMouse = false;
                break;
            case Event.ONMOUSEDOWN:
                Event.setCapture(this.getElement());
                capturedMouse = true;
            case Event.ONMOUSEMOVE:
                if (capturedMouse)
                {
                    DOM.eventPreventDefault(event);

                    int x = DOM.eventGetClientX(event) - colorUnderlay.getAbsoluteLeft() + 1 + Window.getScrollLeft();
                    int y = DOM.eventGetClientY(event) - colorUnderlay.getAbsoluteTop() + 1 + Window.getScrollTop();

                    if (x < 0) x = 0;
                    if (x > 128) x = 128;
                    if (y < 0) y = 0;
                    if (y > 128) y = 128;

                    DOM.setStyleAttribute(slider.getElement(), "left", x - 7 + "px");
                    DOM.setStyleAttribute(slider.getElement(), "top", y - 7 + "px");

                    if (parent != null) { parent.onMapSelected(x,y); }
                }
        }
    }

    /*
     * (non-Javadoc)
     * @see com.google.gwt.user.client.ui.Widget#onLoad()
     */
    @Override
    public void onLoad()
    {
        this.sinkEvents(Event.MOUSEEVENTS);
    }

    /*
     * (non-Javadoc)
     * @see com.google.gwt.user.client.ui.Widget#onUnload()
     */
    @Override
    public void onUnload()
    {
        this.unsinkEvents(Event.MOUSEEVENTS);
    }

    /**
     * *
     * Sets the color selection mode.
     *
     * @param mode Saturation
     */
    public void setColorSelectMode(int mode)
    {
        if (!isAttached()) { return; }

        switch (mode)
        {
            case Saturation:
                colorUnderlay.setResource(cpImageBundle.map_saturation());
                colorOverlay.setResource(cpImageBundle.map_saturation_overlay());
            break;

            case Brightness:
                colorUnderlay.setResource(cpImageBundle.map_white());
                colorOverlay.setResource(cpImageBundle.map_brightness());
            break;

            case Hue:
                colorUnderlay.setResource(cpImageBundle.map_white());
                colorOverlay.setResource(cpImageBundle.map_hue());
                setOverlayOpacity(100);
            break;

            case Red:
                colorOverlay.setResource(cpImageBundle.map_red_max());
                colorUnderlay.setResource(cpImageBundle.map_red_min());
            break;

            case Green:
                colorOverlay.setResource(cpImageBundle.map_green_max());
                colorUnderlay.setResource(cpImageBundle.map_green_min());
            break;

            case Blue:
                colorOverlay.setResource(cpImageBundle.map_blue_max());
                colorUnderlay.setResource(cpImageBundle.map_blue_min());
            break;
        }
    }

    /**
     * Sets the overlay layer's color.
     * @param color Hexadecimal representation of RGB.
     */
    public void setOverlayColor(String color)
    {
        DOM.setStyleAttribute(colorOverlay.getElement(), "backgroundColor", color);
    }

    /**
     * Set overlay layer's opacity.
     * @param alpha An opacity percentage, between 100 (fully opaque) and 0 (invisible).
     */
    public void setOverlayOpacity(int alpha)
    {
        if (alpha >= 0 && alpha <= 100 && isAttached())
        {
            TransparencyImpl.setTransparency(colorOverlay.getElement(), alpha);
        }
    }

    /**
     * Sets the slider's position along the x-axis and y-axis.
     * @param x position along the x-axis [0-128]
     * @param y position along the y-axis [0-128]
     */
    public void setSliderPosition(int x, int y)
    {
        if (x < 0) x = 0;
        if (y < 0) y = 0;
        if (x > 128) x = 128;
        if (y > 128) y = 128;
        DOM.setStyleAttribute(slider.getElement(), "left", x - 7 + "px");
        DOM.setStyleAttribute(slider.getElement(), "top", y - 7 + "px");
    }

    /**
     * Sets the underlay's layer color.
     * @param color Hexadecimal representation of RGB.
     */
    public void setUnderlayColor(String color)
    {
        DOM.setStyleAttribute(colorUnderlay.getElement(), "backgroundColor", color);
    }
}