// @formatter:off
/**
 * Copyright 2010, 2012 Google Inc.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.waveprotocol.wave.client.wavepanel.view.dom.full;

import org.waveprotocol.wave.client.editor.EditorImpl;

import cc.kune.wave.client.resources.KuneWaveResources;

import com.google.gwt.core.client.GWT;
import com.google.gwt.dom.client.StyleInjector;

// TODO: Auto-generated Javadoc
/**
 * This class is responsible for loading all the Css resources needed by the
 * wave panel.
 *
 * @author vjrj@ourproject.org (Vicente J. Ruiz Jurado)
 */
public final class CustomWavePanelResourceLoader {

  /** The Constant blip. */
  private final static BlipViewBuilder.Resources blip = 
       GWT.create(BlipViewBuilder.Resources.class);
  
  /** The Constant collapsible. */
  private final static CollapsibleBuilder.Resources collapsible =
      GWT.create(CollapsibleBuilder.Resources.class);
  
  /** The Constant rootThread. */
  private final static RootThreadViewBuilder.Resources rootThread =
      GWT.create(RootThreadViewBuilder.Resources.class);
  
  /** The Constant replyBox. */
  private final static ReplyBoxViewBuilder.Resources replyBox =
      GWT.create(ReplyBoxViewBuilder.Resources.class);
  
  /** The Constant inlineContinuation. */
  private final static ContinuationIndicatorViewBuilder.Resources inlineContinuation =
    GWT.create(ContinuationIndicatorViewBuilder.Resources.class);
  // Kune patch (but not used yet)
  /** The Constant conversation. */
  private final static KuneWaveResources.Conversation conversation =
      GWT.create(KuneWaveResources.Conversation.class);
  
  /** The Constant participants. */
  private final static ParticipantsViewBuilder.Resources participants =
    GWT.create(ParticipantsViewBuilder.Resources.class);

  static {
    // Inject all CSS synchronously. CSS must be injected synchronously, so that
    // any layout queries, that may happen to occur in the same event cycle,
    // operate on the correct state (GWT's default injection mode is
    // asynchronous). CSS is injected together in one bundle to minimize layout
    // invalidation, and to leave open the possibility of merging stylesheets
    // together for efficiency.
    boolean isSynchronous = true;
    StyleInjector.inject(blip.css().getText(), isSynchronous);
    StyleInjector.inject(collapsible.css().getText(), isSynchronous);
    StyleInjector.inject(rootThread.css().getText(), isSynchronous);
    StyleInjector.inject(replyBox.css().getText(), isSynchronous);
    StyleInjector.inject(inlineContinuation.css().getText(), isSynchronous);
    StyleInjector.inject(conversation.css().getText(), isSynchronous);
    StyleInjector.inject(participants.css().getText(), isSynchronous);
  }

  /**
   * Instantiates a new custom wave panel resource loader.
   */
  private CustomWavePanelResourceLoader() {
  }

  /**
   * Gets the blip.
   *
   * @return the blip
   */
  public static BlipViewBuilder.Resources getBlip() {
    return blip;
  }

  /**
   * Gets the collapsible.
   *
   * @return the collapsible
   */
  public static CollapsibleBuilder.Resources getCollapsible() {
    return collapsible;
  }

  /**
   * Gets the root thread.
   *
   * @return the root thread
   */
  public static RootThreadViewBuilder.Resources getRootThread() {
    return rootThread;
  }

  /**
   * Gets the reply box.
   *
   * @return the reply box
   */
  public static ReplyBoxViewBuilder.Resources getReplyBox() {
    return replyBox;
  }

  /**
   * Gets the continuation indicator.
   *
   * @return the continuation indicator
   */
  public static ContinuationIndicatorViewBuilder.Resources getContinuationIndicator() {
    return inlineContinuation;
  }

  /**
   * Gets the conversation.
   *
   * @return the conversation
   */
  public static KuneWaveResources.Conversation getConversation() {
    return conversation;
  }

  /**
   * Gets the participants.
   *
   * @return the participants
   */
  public static ParticipantsViewBuilder.Resources getParticipants() {
    return participants;
  }

  /**
   * Loads all the CSS required by the wave panel.
   */
  public static void loadCss() {
    // Static initializer loads all the wave panel views.
    // Need a few more:
    EditorImpl.init();
  }

}
